@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -110,7 +110,15 @@ elseif ($empty_btn) {
 
 // Show Type dropdown in header for help items.
 if ($data['popup_type'] === 'help_items') {
-	$cmb_types = new CComboBox('itemtype', $options['itemtype'], 'javascript: reloadPopup(this.form);');
+	$types_select = (new CSelect('itemtype'))
+		->setId('itemtype')
+		->setFocusableElementId('label-itemtype')
+		->setAttribute('autofocus', 'autofocus')
+		->setValue($options['itemtype']);
+
+	$output['script_inline'] .= '$("#itemtype").on("change", (e) => {'.
+		'reloadPopup($(e.target).closest("form").get(0));'.
+	'});';
 
 	$header_form
 		->addVar('srctbl', $data['popup_type'])
@@ -119,13 +127,13 @@ if ($data['popup_type'] === 'help_items') {
 		->addVar('dstfld1', $options['dstfld1']);
 
 	foreach (CControllerPopupGeneric::ALLOWED_ITEM_TYPES as $type) {
-		$cmb_types->addItem($type, item_type2str($type));
+		$types_select->addOption(new CSelectOption($type, item_type2str($type)));
 	}
 
 	$controls[] = [
-		new CLabel(_('Type'), 'itemtype'),
+		new CLabel(_('Type'), $types_select->getFocusableElementId()),
 		(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-		$cmb_types
+		$types_select
 	];
 }
 
@@ -542,12 +550,25 @@ switch ($data['popup_type']) {
 				$graphtype
 			]);
 
+			if ($options['patternselect']) {
+				$graph_name = $graph['name'];
+			}
+			else {
+				if ($data['popup_type'] === 'graphs') {
+					$host_name = $graph['hosts'][0]['name'];
+				}
+				else {
+					$host_names = array_column($graph['hosts'], 'name', 'hostid');
+					$host_name = $host_names[$graph['discoveryRule']['hostid']];
+				}
+
+				$graph_name = $host_name.NAME_DELIMITER.$graph['name'];
+			}
+
 			// For returned data array.
 			$graph = [
 				'id' => $graph['graphid'],
-				'name' => $options['patternselect']
-					? $graph['name']
-					: reset($graph['hosts'])['name'].NAME_DELIMITER.$graph['name']
+				'name' => $graph_name
 			];
 		}
 		unset($graph);
@@ -620,12 +641,7 @@ switch ($data['popup_type']) {
 			else {
 				$script_execute_on = '';
 			}
-			$table->addRow([
-				$check_box,
-				$description,
-				$script_execute_on,
-				zbx_nl2br(htmlspecialchars($script['command'], ENT_COMPAT, 'UTF-8'))
-			]);
+			$table->addRow([$check_box, $description, $script_execute_on, zbx_nl2br($script['command'])]);
 		}
 		unset($data['table_records']);
 		break;
