@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -84,6 +84,7 @@ class CHostGroup extends CApiService {
 			'selectTemplates'						=> null,
 			'selectGroupDiscovery'					=> null,
 			'selectDiscoveryRule'					=> null,
+			'selectHostPrototype'					=> null,
 			'countOutput'							=> false,
 			'groupCount'							=> false,
 			'preservekeys'							=> false,
@@ -1393,8 +1394,8 @@ class CHostGroup extends CApiService {
 	protected function addRelatedObjects(array $options, array $result) {
 		$result = parent::addRelatedObjects($options, $result);
 
-		$groupIds = array_keys($result);
-		sort($groupIds);
+		$groupids = array_keys($result);
+		sort($groupids);
 
 		// adding hosts
 		if ($options['selectHosts'] !== null) {
@@ -1418,7 +1419,7 @@ class CHostGroup extends CApiService {
 			}
 			else {
 				$hosts = API::Host()->get([
-					'groupids' => $groupIds,
+					'groupids' => $groupids,
 					'countOutput' => true,
 					'groupCount' => true
 				]);
@@ -1453,7 +1454,7 @@ class CHostGroup extends CApiService {
 			}
 			else {
 				$hosts = API::Template()->get([
-					'groupids' => $groupIds,
+					'groupids' => $groupids,
 					'countOutput' => true,
 					'groupCount' => true
 				]);
@@ -1472,7 +1473,7 @@ class CHostGroup extends CApiService {
 			$discoveryRules = DBFetchArray(DBselect(
 				'SELECT gd.groupid,hd.parent_itemid'.
 					' FROM group_discovery gd,group_prototype gp,host_discovery hd'.
-					' WHERE '.dbConditionInt('gd.groupid', $groupIds).
+					' WHERE '.dbConditionInt('gd.groupid', $groupids).
 					' AND gd.parent_group_prototypeid=gp.group_prototypeid'.
 					' AND gp.hostid=hd.hostid'
 			));
@@ -1486,11 +1487,38 @@ class CHostGroup extends CApiService {
 			$result = $relationMap->mapOne($result, $discoveryRules, 'discoveryRule');
 		}
 
+		// adding host prototype
+		if ($options['selectHostPrototype'] !== null) {
+			$db_links = DBFetchArray(DBselect(
+				'SELECT gd.groupid,gp.hostid'.
+					' FROM group_discovery gd,group_prototype gp'.
+					' WHERE '.dbConditionInt('gd.groupid', $groupids).
+					' AND gd.parent_group_prototypeid=gp.group_prototypeid'
+			));
+
+			$host_prototypes = API::HostPrototype()->get([
+				'output' => $options['selectHostPrototype'],
+				'hostids' => array_column($db_links, 'hostid'),
+				'preservekeys' => true
+			]);
+
+			foreach ($result as &$row) {
+				$row['hostPrototype'] = [];
+			}
+			unset($row);
+
+			foreach ($db_links as $db_link) {
+				if (array_key_exists($db_link['hostid'], $host_prototypes)) {
+					$result[$db_link['groupid']]['hostPrototype'] = $host_prototypes[$db_link['hostid']];
+				}
+			}
+		}
+
 		// adding group discovery
 		if ($options['selectGroupDiscovery'] !== null) {
 			$groupDiscoveries = API::getApiService()->select('group_discovery', [
 				'output' => $this->outputExtend($options['selectGroupDiscovery'], ['groupid']),
-				'filter' => ['groupid' => $groupIds],
+				'filter' => ['groupid' => $groupids],
 				'preservekeys' => true
 			]);
 			$relationMap = $this->createRelationMap($groupDiscoveries, 'groupid', 'groupid');
