@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@ require_once dirname(__FILE__).'/include/hosts.inc.php';
 
 $page['title'] = _('Availability report');
 $page['file'] = 'report2.php';
-$page['scripts'] = ['class.calendar.js', 'gtlc.js', 'multiselect.js'];
+$page['scripts'] = ['class.calendar.js', 'gtlc.js', 'multiselect.js', 'report2.js'];
 $page['type'] = detect_page_type(PAGE_TYPE_HTML);
 
 require_once dirname(__FILE__).'/include/page_header.php';
@@ -36,9 +36,10 @@ $fields = [
 	'tpl_triggerid' =>		[T_ZBX_INT,			O_OPT,	P_SYS,			DB_ID,		null],
 	'triggerid' =>			[T_ZBX_INT,			O_OPT,	P_SYS|P_NZERO,	DB_ID,		null],
 	// filter
-	'filter_groups' =>		[T_ZBX_INT,			O_OPT,	P_SYS,			DB_ID,		null],
-	'filter_hostids' =>		[T_ZBX_INT,			O_OPT,	P_SYS,			DB_ID,		null],
-	'filter_templateid' =>	[T_ZBX_INT,			O_OPT,	P_SYS,			DB_ID,		null],
+	'filter_groupid' =>		[T_ZBX_INT,			O_OPT,	P_SYS,				DB_ID,		null],
+	'filter_groups' =>		[T_ZBX_INT,			O_OPT,	P_SYS|P_ONLY_ARRAY,	DB_ID,		null],
+	'filter_hostids' =>		[T_ZBX_INT,			O_OPT,	P_SYS|P_ONLY_ARRAY,	DB_ID,		null],
+	'filter_templateid' =>	[T_ZBX_INT,			O_OPT,	P_SYS,				DB_ID,		null],
 	'filter_rst'=>			[T_ZBX_STR,			O_OPT,	P_SYS,			null,		null],
 	'filter_set' =>			[T_ZBX_STR,			O_OPT,	P_SYS,			null,		null],
 	'from' =>				[T_ZBX_RANGE_TIME,	O_OPT,	P_SYS,			null,		null],
@@ -57,7 +58,7 @@ if ($report_mode == AVAILABILITY_REPORT_BY_TEMPLATE) {
 	if (getRequest('hostgroupid') && !isReadableHostGroups([getRequest('hostgroupid')])) {
 		access_deny();
 	}
-	if (getRequest('filter_groups') && !isReadableHostGroups([getRequest('filter_groups')])) {
+	if (getRequest('filter_groupid') && !isReadableHostGroups([getRequest('filter_groupid')])) {
 		access_deny();
 	}
 	if (getRequest('filter_templateid') && !isReadableTemplates([getRequest('filter_templateid')])) {
@@ -74,14 +75,6 @@ if ($report_mode == AVAILABILITY_REPORT_BY_TEMPLATE) {
 		}
 	}
 }
-else {
-	if (getRequest('filter_groupid') && !isReadableHostGroups([getRequest('filter_groupid')])) {
-		access_deny();
-	}
-	if (getRequest('filter_hostid') && !isReadableHosts([getRequest('filter_hostid')])) {
-		access_deny();
-	}
-}
 if (getRequest('triggerid') && !isReadableTriggers([getRequest('triggerid')])) {
 	access_deny();
 }
@@ -93,7 +86,7 @@ $key_prefix = 'web.avail_report.'.$report_mode;
 
 if (hasRequest('filter_set')) {
 	if ($report_mode == AVAILABILITY_REPORT_BY_TEMPLATE) {
-		CProfile::update($key_prefix.'.groupid', getRequest('filter_groups', 0), PROFILE_TYPE_ID);
+		CProfile::update($key_prefix.'.groupid', getRequest('filter_groupid', 0), PROFILE_TYPE_ID);
 		CProfile::update($key_prefix.'.hostid', getRequest('filter_templateid', 0), PROFILE_TYPE_ID);
 		CProfile::update($key_prefix.'.tpl_triggerid', getRequest('tpl_triggerid', 0), PROFILE_TYPE_ID);
 		CProfile::update($key_prefix.'.hostgroupid', getRequest('hostgroupid', 0), PROFILE_TYPE_ID);
@@ -120,7 +113,7 @@ elseif (hasRequest('filter_rst')) {
 $data['filter'] = ($report_mode == AVAILABILITY_REPORT_BY_TEMPLATE)
 	? [
 		// 'Template group' field.
-		'groups' => getRequest('filter_groups', CProfile::get($key_prefix.'.groupid', 0)),
+		'groups' => getRequest('filter_groupid', CProfile::get($key_prefix.'.groupid', 0)),
 		// 'Template' field.
 		'hostids' => getRequest('filter_templateid', CProfile::get($key_prefix.'.hostid', 0)),
 		// 'Template trigger' field.
@@ -192,7 +185,6 @@ else {
 	$select_mode = (new CSelect('mode'))
 		->setValue($report_mode)
 		->setFocusableElementId('mode')
-		->onChange('$(this).closest("form").submit()')
 		->addOption(new CSelectOption(AVAILABILITY_REPORT_BY_HOST, _('By host')))
 		->addOption(new CSelectOption(AVAILABILITY_REPORT_BY_TEMPLATE, _('By trigger template')));
 
@@ -205,7 +197,9 @@ else {
 				(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 				$select_mode
 			])
-	));
+		)
+		->setName('report2')
+	);
 
 	/*
 	 * Filter
@@ -219,7 +213,7 @@ else {
 
 	// Make filter fields.
 	if ($report_mode == AVAILABILITY_REPORT_BY_TEMPLATE) {
-		// Sanitize $data['filter']['groups'] and prepare "Template group" combo box.
+		// Sanitize $data['filter']['groups'] and prepare "Template group" select options.
 		$groups = API::HostGroup()->get([
 			'output' => ['name'],
 			'templated_hosts' => true,
@@ -233,7 +227,7 @@ else {
 			$data['filter']['groups'] = 0;
 		}
 
-		// Sanitize $data['filter']['hostids'] and prepare "Template" combo box.
+		// Sanitize $data['filter']['hostids'] and prepare "Template" select options.
 		$templates = API::Template()->get([
 			'output' => ['name'],
 			'groupids' => $data['filter']['groups'] ? [$data['filter']['groups']] : null,
@@ -249,14 +243,13 @@ else {
 		$select_filter_hostid = (new CSelect('filter_templateid'))
 			->setValue($data['filter']['hostids'])
 			->setFocusableElementId('filter-templateid')
-			->onChange('$(this).closest("form").submit()')
 			->addOption(new CSelectOption(0, _('all')));
 
 		foreach ($templates as $templateid => $template) {
 			$select_filter_hostid->addOption(new CSelectOption($templateid, $template['name']));
 		}
 
-		// Sanitize $data['filter']['tpl_triggerid'] and prepare "Template Trigger" combo box.
+		// Sanitize $data['filter']['tpl_triggerid'] and prepare "Template Trigger" select options.
 		$triggers = API::Trigger()->get([
 			'output' => ['description'],
 			'selectHosts' => ['name'],
@@ -293,7 +286,6 @@ else {
 		$select_tpl_triggerid = (new CSelect('tpl_triggerid'))
 			->setValue($data['filter']['tpl_triggerid'])
 			->setFocusableElementId('tpl-triggerid')
-			->onChange('$(this).closest("form").submit()')
 			->addOption(new CSelectOption(0, _('all')));
 
 		$tpl_triggerids = [];
@@ -305,7 +297,7 @@ else {
 			$tpl_triggerids[$triggerid] = true;
 		}
 
-		// Sanitize $data['filter']['hostgroupid'] and prepare "Host Group" combo box.
+		// Sanitize $data['filter']['hostgroupid'] and prepare "Host Group" select options.
 		$host_groups = API::HostGroup()->get([
 			'output' => ['name'],
 			'monitored_hosts' => true,
@@ -321,7 +313,6 @@ else {
 		$select_hostgroupid = (new CSelect('hostgroupid'))
 			->setValue($data['filter']['hostgroupid'])
 			->setFocusableElementId('hostgroupid')
-			->onChange('$(this).closest("form").submit()')
 			->addOption(new CSelectOption(0, _('all')));
 
 		foreach ($host_groups as $groupid => $group) {
@@ -374,11 +365,10 @@ else {
 			$triggers = [];
 		}
 
-		$select_filter_groupid = (new CSelect('filter_groups'))
+		$select_filter_groupid = (new CSelect('filter_groupid'))
 			->setAttribute('autofocus', 'autofocus')
 			->setValue($data['filter']['groups'])
 			->setFocusableElementId('filter-groups')
-			->onChange('$(this).closest("form").submit()')
 			->addOption(new CSelectOption(0, _('all')));
 
 		foreach ($groups as $groupid => $group) {
@@ -520,14 +510,6 @@ else {
 			$data['filter']['timeline']['to_ts']
 		);
 
-		$url = (new CUrl('report2.php'))->setArgument('triggerid', $trigger['triggerid']);
-		if ($report_mode == AVAILABILITY_REPORT_BY_TEMPLATE) {
-			$url->setArgument('filter_templateid', $data['filter']['hostids']);
-		}
-		else {
-			$url->setArgument('filter_hostids', $trigger['hosts'][0]['hostid']);
-		}
-
 		$triggerTable->addRow([
 			$trigger['host_name'],
 			new CLink($trigger['description'],
@@ -542,7 +524,7 @@ else {
 			($availability['false'] < 0.00005)
 				? ''
 				: (new CSpan(sprintf('%.4f%%', $availability['false'])))->addClass(ZBX_STYLE_GREEN),
-			new CLink(_('Show'), $url)
+			new CLink(_('Show'), (new CUrl('report2.php'))->setArgument('triggerid', $trigger['triggerid']))
 		]);
 	}
 
